<?php

namespace Src\App;

use Src\Controller\CoursesController;
use Src\App\Command\SaveCoursesCommand;
use Src\View\CoursesView;

class FloraLMSPluginService
{
    private $floraLMSAdapter;
    private $repository;
    private $wordpressAdapter;

    public function __construct(FloraLMSAdapterInterface $floraLMSAdapter, RepositoryInterface $repository, WordpressAdapterInterface $wordpressAdapter)
    {
        $this->floraLMSAdapter = $floraLMSAdapter;
        $this->repository = $repository;
        $this->wordpressAdapter = $wordpressAdapter;
    }

    /**
     * @return FloraLMSAdapterInterface
     */
    public function getFloraLMSAdapter()
    {
        return $this->floraLMSAdapter;
    }

    /**
     * @return WordpressAdapterInterface
     */
    public function getWordpressAdapter()
    {
        return $this->wordpressAdapter;
    }

    public function updateCourses()
    {
        $authData = $this->repository->getAuthData();
        if ($authData['secret_key'] === '' || $authData['domain_name'] === '')
        {
            return;
        }
        try
        {
            $courses = $this->floraLMSAdapter->retrieveCoursesList($authData['domain_name'], $this->repository->getUpdatedTime(), $this->wordpressAdapter);
        }
        catch (\RuntimeException $e)
        {
            error_log(print_r($e->getMessage(), 1));
            return;
        }

        $floraLMSAdapter = $this->floraLMSAdapter;
        $this->repository->saveUpdatedTime(date($floraLMSAdapter::DATE_STANDARD));
        $saveCoursesCommand = new SaveCoursesCommand($this->floraLMSAdapter, $this->repository, $this->wordpressAdapter);
        $saveCoursesCommand->execute($courses);
    }

    public function isRegistrationDataProvided()
    {
        $authData = $this->repository->getAuthData();
        return !($authData['secret_key'] === '' || $authData['domain_name'] === '');
    }

    public function saveSecretKey($input)
    {
        $this->repository->saveSecretKey($input);
        return $input;
    }

    public function saveDomainName($input)
    {
        $this->repository->saveDomain($input);
        return $input;
    }

    public function retrieveRedirectUrlGoToCourseAction($email, $urlToCourse)
    {
        $floraLMSAdapter = $this->floraLMSAdapter;
        return $email === 'null' ? $urlToCourse : $this->floraLMSAdapter->generateJWTLink($email, $this->repository->getAuthData()) . $floraLMSAdapter::REDIRECT_URL . $urlToCourse;
    }

    public function retrieveRedirectUrlGoToFloraAction($email)
    {
        $floraLMSAdapter = $this->getFloraLMSAdapter();
        return $email === 'null' ? $floraLMSAdapter::REQUEST_PROTOCOL . $this->repository->getAuthData()['domain_name'] . $floraLMSAdapter::FLORA_HTTP_POSTFIX : $this->floraLMSAdapter->generateJWTLink($email, $this->repository->getAuthData());
    }

    public function activate()
    {
        $this->wordpressAdapter->flushRewriteRules();
        $this->wordpressAdapter->insertCoursesPage(CoursesView::COURSE_PAGE_NAME);
        $this->wordpressAdapter->addActivatedPluginAction(array($this->repository, 'register'));
    }

    public function deactivate()
    {
        $this->wordpressAdapter->flushRewriteRules();
        $this->wordpressAdapter->unregisterPostType(CoursesController::COURSE_POST_TYPE_NAME);
        $this->repository->clearData();
    }

}