<?php

namespace Src\App;

interface WordpressAdapterInterface extends HttpClientInterface
{
    /**
     * @param array $callable
     * @return mixed
     */
    public function registerActivationCallback($callable);

    /**
     * @param array $callable
     * @return void
     */
    public function registerDeactivationCallback($callable);

    /**
     * @param $postTypeName
     * @return void
     */
    public function registerCustomPostType($postTypeName);

    /**
     * @param array $callable
     * @return void
     */
    public function addActivatedPluginAction($callable);

    /**
     * @return void
     */
    public function flushRewriteRules();

    /**
     * @param $postType
     * @return void
     */
    public function unregisterPostType($postType);

    /**
     * @param $id
     * @return string
     */
    public function getFieldValueById($id);

    /**
     * @param array $callable
     * @return void
     */
    public function addAdminMenuAction($callable);

    /**
     * @param array $page
     * @return void
     */
    public function addAdminMenuPage(array $page);

    /**
     * @param array $settings
     * @param array $sections
     * @param array $fields
     * @return void
     */
    public function registerAdminFields(array $settings, array $sections, array $fields);

    /**
     * @param array $callable
     * @return void
     */
    public function addActionOnInitialization($callable);

    /**
     * @param array $callable
     * @return void
     */
    public function addFilterOnDeletePost($callable);

    /**
     * @param array $callable
     * @return void
     */
    public function addFilterOnTrashPost($callable);

    /**
     * @param array $post
     * @return string
     */
    public function insertPost(array $post);

    /**
     * @return string
     */
    public function getRestUrl();

    /**
     * @return WP_User
     */
    public function getCurrentUser();

    /**
     * @param string $namespace
     * @param string $restParam
     * @param array $args
     * @return void
     */
    public function registerAction($namespace, $restParam, $args);

    /**
     * @param array $callable
     * @return void
     */
    public function registerSettingsLinks($callable);

    /**
     * @param array $callable
     * @return void
     */
    public function addActionToTemplates($callable);

    /**
     * @param string $pageName
     * @return void
     */
    public function insertCoursesPage($pageName);

    /**
     * @return string
     */
    public function getPluginFilePath();

    /**
     * @param string $path
     * @return string
     */
    public function concatenateWithPluginUrl($path);

    /**
     * @return string
     */
    public function retrievePluginDirPath();

    /**
     * @param Course $course
     * @param $actionUrl
     * @return string
     */
    public function getCourseContentHtml(Course $course, $actionUrl);
}