<?php

namespace Src\App\Command;

use Src\App\Course;
use Src\App\FloraLMSAdapterInterface;
use Src\App\RepositoryInterface;
use Src\App\WordpressAdapterInterface;
use Src\Controller\CoursesController;

class SaveCoursesCommand
{
    private $floraLMSAdapter;
    private $repository;
    private $wordpressAdapter;

    public function __construct(FloraLMSAdapterInterface $floraLMSAdapter, RepositoryInterface $repository, WordpressAdapterInterface $wordpressAdapter)
    {
        $this->floraLMSAdapter = $floraLMSAdapter;
        $this->repository = $repository;
        $this->wordpressAdapter = $wordpressAdapter;
    }

    public function execute($courses)
    {
        if (count($courses) === 0)
        {
            return;
        }

        $coursesConf = $this->repository->getCoursesRelatedArray();

        foreach ($courses as $course)
        {
            $localId = $this->getIdFromConfArray($course['uuid'], $coursesConf);
            $newCourse = new Course($course['uuid'], $localId, $course['title'], $course['description'], $course['thumbnail_url'], $course['url'], $course['is_deleted']);
            if ($localId !== null)
            {
                if ($newCourse->getIsDeleted() === true)
                {
                    $this->repository->removeCourse($newCourse->getLocalId());
                    continue;
                }
                $this->repository->updateCourse($localId, $course['title'], $this->getCourseContentHtml($newCourse));
                continue;
            }
            if ($newCourse->getIsDeleted() !== true)
            {
                $id = $this->insertCourse($newCourse);
                $this->repository->updateRelatedArray($id, $newCourse->getFloraUuid());
            }
        }
    }

    private function getIdFromConfArray($id, $coursesConf)
    {
        foreach ($coursesConf as $conf)
        {
            if ($conf['post_id_flora'] === $id)
            {
                return $conf['post_id_local'];
            }
        }
        return null;
    }

    /**
     * @param Course $course
     * @return string courseId
     */
    private function insertCourse(Course $course)
    {
        return $this->wordpressAdapter->insertPost(array(
            'post_title' => $course->getTitle(),
            'post_content' => $this->getCourseContentHtml($course),
            'post_status' => 'publish',
            'post_author' => $this->wordpressAdapter->getCurrentUser()->ID,
            'post_type' => CoursesController::COURSE_POST_TYPE_NAME,
        ));
    }

    /**
     * @param Course $course
     * @return string
     */
    private function getCourseContentHtml(Course $course)
    {
        return $this->wordpressAdapter->getCourseContentHtml($course, $this->floraLMSAdapter->getActionUrl($this->wordpressAdapter->getRestUrl()));
    }
}