<?php

namespace Src\Controller;

use Src\App\FloraLMSPluginService;

class RedirectController
{

    private $floraLMSPluginService;

    public function __construct(FloraLMSPluginService $floraLMSPluginService)
    {
        $this->floraLMSPluginService = $floraLMSPluginService;
    }

    public function register()
    {
        $floraLMSAdapter = $this->floraLMSPluginService->getFloraLMSAdapter();

        $args = array(
            'methods' => 'GET',
            /** @see RedirectController::goToFloraCourseAction() **/
            'callback' => array($this, 'goToFloraCourseAction'),
            'args' => array(
                $floraLMSAdapter::EMAIL_PARAM => array(
                    'type' => 'string',
                    'default' => $this->retrieveUserEmail()
                )
            ),
        );
        $this->floraLMSPluginService->getWordpressAdapter()->registerAction($floraLMSAdapter::REST_NAMESPACE, '/' . $floraLMSAdapter::REST_REF_PARAM . '=' . $floraLMSAdapter::REST_CONTENT_LINK_PARAM, $args);

        $args = array(
            'methods' => 'GET',
            /** @see RedirectController::goToFloraAction() **/
            'callback' => array($this, 'goToFloraAction'),
            'args' => array(
                $floraLMSAdapter::EMAIL_PARAM => array(
                    'type' => 'string',
                    'default' => $this->retrieveUserEmail()
                )
            ),
        );
        $this->floraLMSPluginService->getWordpressAdapter()->registerAction($floraLMSAdapter::REST_NAMESPACE, $floraLMSAdapter::REST_GO_TO_FLORA, $args);
    }

    public function retrieveUserEmail()
    {
        $currentUser = $this->floraLMSPluginService->getWordpressAdapter()->getCurrentUser();
        if (!$currentUser || !$currentUser->user_email) {
            return 'null';
        }
        return $currentUser->user_email;
    }

    public function goToFloraCourseAction(\WP_REST_Request $request)
    {
        $floraLMSAdapter = $this->floraLMSPluginService->getFloraLMSAdapter();

        $urlToCourse = $request->get_param($floraLMSAdapter::REST_REF_PARAM);
        $email = $request->get_param($floraLMSAdapter::EMAIL_PARAM);
        $redirectUrl = $this->floraLMSPluginService->retrieveRedirectUrlGoToCourseAction($email, $urlToCourse);
        $response = new \WP_REST_Response(200, array('Location' => $redirectUrl));
        $response->header('Location', $redirectUrl, true);
        return $response;
    }

    public function goToFloraAction(\WP_REST_Request $request)
    {
        $floraLMSAdapter = $this->floraLMSPluginService->getFloraLMSAdapter();

        $email = $request->get_param($floraLMSAdapter::EMAIL_PARAM);
        $redirectUrl = $this->floraLMSPluginService->retrieveRedirectUrlGoToFloraAction($email);
        $response = new \WP_REST_Response(200, array('Location' => $redirectUrl));
        $response->header('Location', $redirectUrl, true);
        return $response;
    }
}