<?php

namespace Src\Infrastructure;

use Src\App\RepositoryInterface;

class Repository implements RepositoryInterface
{
    const TABLE_NAME_CONF = 'flora_config';
    const TABLE_NAME_COURSES = 'flora_course';

    public function register()
    {
        $this->initializeConfTable();
        $this->initializeCoursesTable();
    }

    private function initializeConfTable()
    {

        global $wpdb;

        $tableName = self::TABLE_NAME_CONF;
        $query = "DROP TABLE IF EXISTS $tableName";
        $wpdb->query($query);
        $query = "CREATE TABLE $tableName(
            id INT NOT NULL AUTO_INCREMENT,
            secret_key VARCHAR(255),
            domain_name VARCHAR(50),
            update_time TIMESTAMP,
            PRIMARY KEY(ID)
        )";
        $wpdb->query($query);
        $wpdb->insert($tableName, array(
            'secret_key' => '',
            'domain_name' => '',
            'update_time' => 0,
        ), '%s');
    }

    private function initializeCoursesTable()
    {
        global $wpdb;

        $tableName = self::TABLE_NAME_COURSES;
        $query = "DROP TABLE IF EXISTS $tableName";
        $wpdb->query($query);
        $query = "CREATE TABLE $tableName(
            id INT NOT NULL AUTO_INCREMENT,
            post_id_local INT NOT NULL,
            post_id_flora VARCHAR(255) NOT NULL,
            PRIMARY KEY(ID)
        )";
        $wpdb->query($query);
    }

    /**
     * @param string $key
     */
    public function saveSecretKey($key)
    {
        global $wpdb;

        $tableName = self::TABLE_NAME_CONF;
        $wpdb->query($wpdb->prepare("UPDATE $tableName SET update_time = '0', secret_key = %s LIMIT 1", $key));
    }

    /**
     * @param string $domain
     */
    public function saveDomain($domain)
    {
        global $wpdb;

        $tableName = self::TABLE_NAME_CONF;
        $wpdb->query($wpdb->prepare("UPDATE $tableName SET update_time = '0', domain_name = %s LIMIT 1", $domain));
    }

    /**
     * @return array
     */
    public function getAuthData()
    {
        global $wpdb;
        $tableName = self::TABLE_NAME_CONF;
        $authData = $wpdb->get_row("SELECT secret_key, domain_name FROM $tableName LIMIT 1;");
        return array(
            'secret_key' => $authData->secret_key,
            'domain_name' => $authData->domain_name,
        );
    }

    /**
     * @return array
     */
    public function getCoursesRelatedArray()
    {
        global $wpdb;

        $tableName = self::TABLE_NAME_COURSES;
        $query = "SELECT post_id_flora, post_id_local FROM $tableName;";
        return $wpdb->get_results($query, ARRAY_A);
    }

    /**
     * @param string $localId
     * @param string $floraId
     */
    public function updateRelatedArray($localId, $floraId)
    {
        global $wpdb;

        $wpdb->insert(
            self::TABLE_NAME_COURSES,
            array(
                'post_id_local' => $localId,
                'post_id_flora' => $floraId
            ),
            array(
                '%s', '%s'
            )
        );
    }

    /**
     * @param string $updatedTime
     */
    public function saveUpdatedTime($updatedTime)
    {
        global $wpdb;

        $tableName = self::TABLE_NAME_CONF;
        $wpdb->query("UPDATE $tableName SET update_time = '$updatedTime' LIMIT 1");
    }

    /**
     * @return string
     */
    public function getUpdatedTime()
    {
        global $wpdb;

        $tableName = self::TABLE_NAME_CONF;
        $row = $wpdb->get_row("SELECT update_time FROM $tableName LIMIT 1;");
        return $row->update_time;
    }

    public function clearData()
    {
        global $wpdb;

        $tableName = self::TABLE_NAME_CONF;
        $query = "DROP TABLE IF EXISTS $tableName";
        $wpdb->query($query);

        $tableName = self::TABLE_NAME_COURSES;
        $query = "DROP TABLE IF EXISTS $tableName";
        $wpdb->query($query);

        $coursePage = get_page_by_title($this->coursePageName);
        wp_delete_post($coursePage);

        $wpdb->query("DELETE FROM wp_posts WHERE post_type = 'course';");
    }

    /**
     * @param string $localId
     * @param string $title
     * @param string $courseContent
     */
    public function updateCourse($localId, $title, $courseContent)
    {
        global $wpdb;

        $wpdb->update(
            'wp_posts',
            array(
                'post_title' => $title,
                'post_content' => $courseContent
            ),
            array(
                'ID' => $localId
            ),
            '%s'
        );
    }

    /**
     * @param string $localId
     */
    public function removeCourse($localId)
    {
        global $wpdb;

        wp_delete_post($localId, true);
        $wpdb->delete(
            self::TABLE_NAME_COURSES,
            array(
                'post_id_local' => $localId
            ),
            array(
                '%s'
            )
        );
    }

}
