<?php

namespace Src;

use Src\App\FloraLMSPluginService;
use Src\Controller\RedirectController;
use Src\Controller\SettingsController;
use Src\Controller\CoursesController;
use Src\View\CoursesView;

final class Init
{
    public static function registerService()
    {
        $floraLMSAdapter = new Infrastructure\FloraLMSAdapter();
        $repository = new Infrastructure\Repository();
        $wordpressAdapter = new Infrastructure\WordpressAdapter();

        $floraLMSPluginService =  new App\FloraLMSPluginService($floraLMSAdapter, $repository, $wordpressAdapter);

        self::activateServices($floraLMSPluginService);
    }

    private static function activateServices(FloraLMSPluginService $floraLMSPluginService)
    {
        self::registerHooks($floraLMSPluginService);
        self::registerSettings($floraLMSPluginService);
        self::registerCourses($floraLMSPluginService);
        self::registerRedirect($floraLMSPluginService);
    }

    private static function registerHooks(FloraLMSPluginService $floraLMSPluginService)
    {
        /** @see FloraLMSPluginService::activate() **/
        $floraLMSPluginService->getWordpressAdapter()->registerActivationCallback(array($floraLMSPluginService, 'activate'));
        /** @see FloraLMSPluginService::deactivate() **/
        $floraLMSPluginService->getWordpressAdapter()->registerDeactivationCallback(array($floraLMSPluginService, 'deactivate'));
    }

    private static function registerSettings(FloraLMSPluginService $floraLMSPluginService)
    {
        $settingsController = new SettingsController($floraLMSPluginService);
        /** @see SettingsController::register() **/
        $floraLMSPluginService->getWordpressAdapter()->addActionOnInitialization(array($settingsController, 'register'));
    }

    private static function registerCourses(FloraLMSPluginService $floraLMSPluginService)
    {
        $coursesController = new CoursesController($floraLMSPluginService);
        $coursesController->register();
        /** @see CoursesView::updateCoursesTemplate() **/
        $floraLMSPluginService->getWordpressAdapter()->addActionToTemplates(array(new CoursesView($floraLMSPluginService->getWordpressAdapter()), 'updateCoursesTemplate'));
    }

    private static function registerRedirect(FloraLMSPluginService $floraLMSPluginService)
    {
        $redirectController = new RedirectController($floraLMSPluginService);
        /** @see RedirectController::register() **/
        $floraLMSPluginService->getWordpressAdapter()->addActionOnInitialization(array($redirectController, 'register'));
    }
}
